.. GasNetSim documentation master file, created by
sphinx-quickstart on Sat Mar 26 01:09:53 2022.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive.

Welcome to GasNetSim's documentation!
=====================================


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
